@@ -3,8 +3,9 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Glorified metronome
 
-our $VERSION = '0.1502';
+our $VERSION = '0.1600';
 
+use Math::Bezier;
 use MIDI::Simple;
 use Music::Duration;
 use Moo;
@@ -297,24 +298,39 @@ sub roll {
 sub crescendo_roll {
     my ($self, $span, $length, $spec, $patch) = @_;
     $patch ||= $self->snare;
-    my ($i, $j) = @$span;
+    my ($i, $j, $bezier) = @$span;
     my $x = $MIDI::Simple::Length{$length};
     my $y = $MIDI::Simple::Length{$spec};
     my $z = sprintf '%0.f', $x / $y;
-    my $v = sprintf '%0.f', ($j - $i) / ($z - 1);
-#    warn(__PACKAGE__,' ',__LINE__," VALUE: ",$v,"\n");
-    for my $n (1 .. $z) {
-        if ($n == $z) {
-            if ($i < $j) {
-                $i += $j - $i;
+    if ($bezier) {
+        my $bezier = Math::Bezier->new(
+            1, $i,
+            $z, $i,
+            $z, $j,
+        );
+        for (my $n = 0; $n <= 1; $n += (1 / ($z - 1))) {
+            my (undef, $v) = $bezier->point($n);
+            $v = sprintf '%0.f', $v;
+#            warn(__PACKAGE__,' ',__LINE__," $n INC: $v\n");
+            $self->accent_note($v, $spec, $patch);
+        }
+    }
+    else {
+        my $v = sprintf '%0.f', ($j - $i) / ($z - 1);
+#        warn(__PACKAGE__,' ',__LINE__," VALUE: $v\n");
+        for my $n (1 .. $z) {
+            if ($n == $z) {
+                if ($i < $j) {
+                    $i += $j - $i;
+                }
+                elsif ($i > $j) {
+                    $i -= $i - $j;
+                }
             }
-            elsif ($i > $j) {
-                $i -= $i - $j;
-            }
+#            warn(__PACKAGE__,' ',__LINE__," $n INC: $i\n");
+            $self->accent_note($i, $spec, $patch);
+            $i += $v;
         }
-#        warn(__PACKAGE__,' ',__LINE__," $n INC: ",$i,"\n");
-        $self->accent_note($i, $spec, $patch);
-        $i += $v;
     }
 }
 
@@ -355,7 +371,7 @@ MIDI::Drummer::Tiny - Glorified metronome
 
 =head1 VERSION
 
-version 0.1502
+version 0.1600
 
 =head1 SYNOPSIS
 
@@ -381,7 +397,7 @@ version 0.1502
  $d->metronome44;  # 4/4 time for the number of bars
 
  $d->flam($d->quarter, $d->snare);
- $d->roll($d->eighth, $d->thirtysecond);
+ $d->crescendo_roll([50, 127], $d->eighth, $d->thirtysecond);
 
  # Alternate kick and snare
  $d->note($d->quarter, $d->open_hh, $_ % 2 ? $d->kick : $d->snare)
@@ -602,11 +618,14 @@ If not provided the B<snare> is used for the B<patch>.
 
 =head2 crescendo_roll
 
-  $d->crescendo_roll( [$i, $j], $length, $spec, $patch );
+  $d->crescendo_roll( [$start, $end, $bezier], $length, $spec, $patch );
 
 Add a drum roll to the score, where the B<patch> is played for
 duration B<length> in B<spec> notes, at increasing or decreasing
-volumes from B<i> to B<j>.
+volumes from B<start> to B<end>.
+
+If true, the B<bezier> flag will render the crescendo with a curve,
+rather than as a straight line.
 
 If not provided the B<snare> is used for the B<patch>.
 
